from setuptools import setup

setup(
    name='git-rename-authors',
    version='0.1.0',
    author='Guillaume Vincent',
    author_email='guillaume@oslab.fr',
    scripts=['git-rename-authors'],
    packages=['git_rename_authors'],   
    url='https://github.com/guillaumevincent/git-rename-authors',
    license='MIT',
    description='GUI to clean git repository authors'
)
